Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(579)

Unified Diff: chrome/browser/instant/instant_loader.h

Issue 11359198: Implement the Instant extended API startMargin, endMargin, and rtl properties and the onmarginchang… (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/instant/instant_loader.h
diff --git a/chrome/browser/instant/instant_loader.h b/chrome/browser/instant/instant_loader.h
index 3837b87997eaadbe2a79ba4f47a75b88b2225371..2d72251edaf407464e90dcc1beaa81cfb8333d1d 100644
--- a/chrome/browser/instant/instant_loader.h
+++ b/chrome/browser/instant/instant_loader.h
@@ -60,10 +60,15 @@ class InstantLoader : public content::NotificationObserver {
// is taken as the exact query (no prediction is made).
void Update(const string16& user_text, bool verbatim);
// Tells the preview page of the bounds of the omnibox dropdown (in screen
// coordinates). This is used by the page to offset the results to avoid them
// being covered by the omnibox dropdown.
- void SetOmniboxBounds(const gfx::Rect& bounds);
+ void SetPopupBounds(const gfx::Rect& bounds);
+
+ // Tells the preview page what size margins to use. Both |start| and |end|
+ // are offsets from the start edge of the page delimiting the horizontal
+ // bounds of the page text area.
+ void SetMarginSize(int start, int end);
// Tells the preview page about the available autocomplete results.
void SendAutocompleteResults(
@@ -60,10 +60,15 @@ class InstantLoader : public content::NotificationObserver {
// is taken as the exact query (no prediction is made).
void Update(const string16& user_text, bool verbatim);
- // Tells the preview page of the bounds of the omnibox dropdown (in screen
+ // Tells the preview page of the bounds of the omnibox popup (in screen
// coordinates). This is used by the page to offset the results to avoid them
// being covered by the omnibox dropdown.

Powered by Google App Engine
This is Rietveld 408576698